@@ -22,7 +22,7 @@ Net::Etcd::Role::Actions
 
 =cut
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
 
 has etcd => (
     is  => 'ro',
@@ -84,8 +84,16 @@ sub init {
 
 =cut
 
-has headers => ( is => 'ro' );
+has headers => ( is => 'lazy' );
 
+sub _build_headers {
+    my ($self) = @_;
+    my $headers;
+    my $token = $self->etcd->auth_token;
+    $headers->{'Content-Type'} = 'application/json';
+    $headers->{'Authorization'} = $token if $token;
+    return $headers;
+}
 =head2 hold
 
 When set will not fire request.
@@ -113,6 +121,7 @@ sub _build_request {
     my $cb = $self->cb;
     my $cv = $self->cv ? $self->cv : AE::cv;
     $cv->begin;
+
     http_request(
         'POST',
         $self->etcd->api_path . $self->{endpoint},
